@@ -1,5 +1,5 @@
 /*
- * Copyright 2002, The libsigc++ Development Team
+ * Copyright 2002 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -16,38 +16,38 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
-#ifndef _SIGC_REFERENCE_WRAPPER_H_
-#define _SIGC_REFERENCE_WRAPPER_H_
+#ifndef SIGC_REFERENCE_WRAPPER_H
+#define SIGC_REFERENCE_WRAPPER_H
 
 namespace sigc
 {
 
-template <class T_type>
+template <typename T_type>
 struct unwrap_reference
 {
   using type = T_type;
 };
 
-template <class T_type>
+template <typename T_type>
 struct unwrap_reference<std::reference_wrapper<T_type>>
 {
   using type = T_type&;
 };
 
-template <class T_type>
+template <typename T_type>
 struct unwrap_reference<std::reference_wrapper<const T_type>>
 {
   using type = const T_type&;
 };
 
-template <class T_type>
+template <typename T_type>
 T_type&
 unwrap(const std::reference_wrapper<T_type>& v)
 {
   return v;
 }
 
-template <class T_type>
+template <typename T_type>
 const T_type&
 unwrap(const std::reference_wrapper<const T_type>& v)
 {
@@ -56,4 +56,4 @@ unwrap(const std::reference_wrapper<const T_type>& v)
 
 } /* namespace sigc */
 
-#endif /* _SIGC_REFERENCE_WRAPPER_H_ */
+#endif /* SIGC_REFERENCE_WRAPPER_H */
