@@ -24,7 +24,8 @@ namespace internal
 {
 
 // Data sent from signal_impl::insert() to slot_rep::set_parent() when a slot is
-// connected, and then sent from slot_rep::disconnect() to signal_impl::notify()
+// connected, and then sent from slot_rep::disconnect() to
+// signal_impl::notify_self_and_iter_of_invalidated_slot()
 // when the slot is disconnected. Bug 167714.
 struct self_and_iter : public notifiable
 {
@@ -63,22 +64,30 @@ signal_impl::operator delete(void* p)
 void
 signal_impl::clear()
 {
-  // Don't let signal_impl::notify() erase the slots. It would invalidate the
-  // iterator in the following loop.
+  // Don't let signal_impl::notify_self_and_iter_of_invalidated_slot() erase the slots.
+  // It would invalidate the iterator in the following loop.
   // Don't call shared_from_this() here. clear() is called from the destructor.
   // When the destructor is executing, shared_ptr's use_count has reached 0,
   // and it's no longer possible to get a shared_ptr to this.
+  const bool during_signal_emission = exec_count_ > 0;
   const bool saved_deferred = deferred_;
   signal_impl_exec_holder exec(this);
 
   // Disconnect all connected slots before they are deleted.
-  // signal_impl::notify() will be called and delete the self_and_iter structs.
+  // signal_impl::notify_self_and_iter_of_invalidated_slot() will be called and
+  // delete the self_and_iter structs.
   for (auto& slot : slots_)
     slot.disconnect();
 
-  deferred_ = saved_deferred;
-
-  slots_.clear();
+  // Don't clear slots_ during signal emission. Provided deferred_ is true,
+  // sweep() will be called from ~signal_impl_holder() after signal emission,
+  // and it will erase all disconnected slots.
+  // https://bugzilla.gnome.org/show_bug.cgi?id=784550
+  if (!during_signal_emission)
+  {
+    deferred_ = saved_deferred;
+    slots_.clear();
+  }
 }
 
 signal_impl::size_type
@@ -119,23 +128,6 @@ signal_impl::connect(slot_base&& slot_)
   return insert(slots_.end(), std::move(slot_));
 }
 
-signal_impl::iterator_type
-signal_impl::erase(iterator_type i)
-{
-  // Don't let signal_impl::notify() erase the slot. It would be more
-  // difficult to get the correct return value from signal_impl::erase().
-  const bool saved_deferred = deferred_;
-  signal_impl_holder exec(shared_from_this());
-
-  // Disconnect the slot before it is deleted.
-  // signal_impl::notify() will be called and delete the self_and_iter struct.
-  i->disconnect();
-
-  deferred_ = saved_deferred;
-
-  return slots_.erase(i);
-}
-
 void
 signal_impl::add_notification_to_iter(const signal_impl::iterator_type& iter)
 {
@@ -205,7 +197,7 @@ signal_impl::notify_self_and_iter_of_invalidated_slot(notifiable* d)
     // This is occurring during signal emission or slot erasure.
     // => sweep() will be called from ~signal_impl_holder() after signal emission.
     // This is safer because we don't have to care about our
-    // iterators in emit(), clear(), and erase().
+    // iterators in emit() and clear().
     self->deferred_ = true;
   }
 }
@@ -286,12 +278,6 @@ signal_base::insert(iterator_type i, slot_base&& slot_)
   return impl()->insert(i, std::move(slot_));
 }
 
-signal_base::iterator_type
-signal_base::erase(iterator_type i)
-{
-  return impl()->erase(i);
-}
-
 signal_base&
 signal_base::operator=(const signal_base& src)
 {
