@@ -1,5 +1,5 @@
 /*
- * Copyright 2002, The libsigc++ Development Team
+ * Copyright 2002 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -16,36 +16,36 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
-#ifndef _SIGC_TYPE_TRAIT_H_
-#define _SIGC_TYPE_TRAIT_H_
+#ifndef SIGC_TYPE_TRAIT_H
+#define SIGC_TYPE_TRAIT_H
 
 #include <sigc++config.h>
 
 namespace sigc
 {
 
-template <class T_type>
+template <typename T_type>
 struct type_trait
 {
   using pass = T_type&;
   using take = const T_type&;
 };
 
-template <class T_type, int N>
+template <typename T_type, int N>
 struct type_trait<T_type[N]>
 {
   using pass = T_type*&;
   using take = const T_type*&;
 };
 
-template <class T_type>
+template <typename T_type>
 struct type_trait<T_type&>
 {
   using pass = T_type&;
   using take = T_type&;
 };
 
-template <class T_type>
+template <typename T_type>
 struct type_trait<const T_type&>
 {
   using pass = const T_type&;
@@ -67,4 +67,4 @@ using type_trait_take_t = typename type_trait<T>::take;
 
 } /* namespace sigc */
 
-#endif /* _SIGC_TYPE_TRAIT_H_ */
+#endif /* SIGC_TYPE_TRAIT_H */
